@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.060 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.061 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.060 ;
-use IO::Uncompress::Adapter::UnXz 2.060 ;
+use IO::Uncompress::Base 2.061 ;
+use IO::Uncompress::Adapter::UnXz 2.061 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnXzError);
 
-$VERSION = '2.060';
+$VERSION = '2.061';
 $UnXzError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -37,7 +37,7 @@ sub unxz
 }
 
 our %PARAMS = (
-        'memLimit' => [IO::Compress::Base::Common::Parse_unsigned, 128 * 1024 * 1024],
+        'memlimit' => [IO::Compress::Base::Common::Parse_unsigned, 128 * 1024 * 1024],
         'flags'    => [IO::Compress::Base::Common::Parse_boolean,  0],
     );    
 
@@ -225,7 +225,7 @@ section.
 
 The functional interface needs Perl5.005 or better.
 
-=head2 unxz $input => $output [, OPTS]
+=head2 unxz $input_filename_or_reference => $output_filename_or_reference [, OPTS]
 
 C<unxz> expects at least two parameters,
 C<$input_filename_or_reference> and C<$output_filename_or_reference>.
